==> snEADy1.0.zip: src/de/farafin/snEADy/player/LevelInfo.java <==
/*
 * Created on 07.02.2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package de.farafin.snEADy.player;

/** This is just a class for storing informations. It doesnt contain methods because it doesnt need
 * to calculate anything. Its just a set of informations for the player. <br>
 *  <br>
 * This class contains all imprortant Informations about the playfield. <br> 
 *  <br>
 * Diese Klasse ist zum Speichern von Informationen gedacht. Sie enthllt keine Methoden weil
 * sie nichts berechnen muss. Es ist nur eine Menge von Informationen fr den Spieler. <br>
 * <br>
 * Diese Klasse enthllt alle wichtigen Informationen ber das Spielfeld. 
 * 
 * @author roland, lars
 */
public class LevelInfo
{
	/** The name of the Level / playfield<br>
	 * <br>
	 * Der Name des Levels / Spielfeldes.
	 * 
	 *  */
	public String levelName = "";

	/** The height of the playField (the same value as playField.length)<br>
	 * <br>
	 * Die Hhe des Spielfeldes (der gleiche Wert wie auch playField.length)
	 * */
	public int height = 0;
	
	/** The width of playField (the same value as playField[0].length)<br>
	 * <br>
	 * Die Breite des Spielfeldes (dar gleiche Wert wie auch playField[0].length)
	 */
	public int width = 0;
	
	/** The playfield. It is a 2 dimensional array of char values. For more informations about the
	 * meaning of this values visit PubConstants. The play field is stored like a matrix
	 * (visit Horst's script around page 63). The upper left corner is the origin with coordinats (0, 0).
	 * The first index represents the line, the second the row. The playfield cells are adressed
	 * with playField[line][row]. Please don't get deranged by this, we had to decide
	 * for one representation and we choosed this one. If you learn this representation for one
	 * time, you will never be confused again which index of Horst's matrixes means the line or row...<br>
	 * <br>
	 * Das Spielfeld. Es ist ein 2-Dimensionaler Array von char-Werten. Mehr ber deren Bedeutung siehe
	 * PubConstants. Das Spielfeld wird wie eine Matrix gespeichert (siehe Horst's Skript ungefr Seite 63).
	 * Die obere linke Ecke ist der Ursprung mit den Koordinaten (0, 0). Der erste Index reprsentiert die
	 * Zeile, der zweite die Spalte. Die Spielfeldzellen werden mit playFiled[line][row] adressiert.
	 * Bitte lasst euch davon nicht verwirren, wir mussten uns fr eine Darstellung entscheiden und
	 * haben diese gewhlt. Wenn ihr diese Darstellung ein mal gelernt habt, werdet ihr euch nie
	 * wieder von den Indizes von Horsts Matrizen irritieren lassen ;-).
	 * 
	 * @see PubConstants
	 */
	public char [][]playField = null;
}

==> snEADy1.019.zip: src/de/farafin/snEADy/player/LevelInfo.java <==
/*
 * Created on 07.02.2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package de.farafin.snEADy.player;

import java.io.Serializable;

/** This is just a class for storing informations. It doesnt contain methods because it doesnt need
 * to calculate anything. Its just a set of informations for the player. <br>
 *  <br>
 * This class contains all imprortant Informations about the playfield. <br> 
 *  <br>
 * Diese Klasse ist zum Speichern von Informationen gedacht. Sie enthllt keine Methoden weil
 * sie nichts berechnen muss. Es ist nur eine Menge von Informationen fr den Spieler. <br>
 * <br>
 * Diese Klasse enthllt alle wichtigen Informationen ber das Spielfeld. 
 * 
 * @author roland, lars
 */
public class LevelInfo implements Serializable
{
	/** The name of the Level / playfield<br>
	 * <br>
	 * Der Name des Levels / Spielfeldes.
	 * 
	 *  */
	public String levelName = "";

	/** The height of the playField (the same value as playField.length)<br>
	 * <br>
	 * Die Hhe des Spielfeldes (der gleiche Wert wie auch playField.length)
	 * */
	public int height = 0;
	
	/** The width of playField (the same value as playField[0].length)<br>
	 * <br>
	 * Die Breite des Spielfeldes (dar gleiche Wert wie auch playField[0].length)
	 */
	public int width = 0;
	
	/** The playfield. It is a 2 dimensional array of char values. For more informations about the
	 * meaning of this values visit PubConstants. The play field is stored like a matrix
	 * (visit Horst's script around page 63). The upper left corner is the origin with coordinats (0, 0).
	 * The first index represents the line, the second the row. The playfield cells are adressed
	 * with playField[line][row]. Please don't get deranged by this, we had to decide
	 * for one representation and we choosed this one. If you learn this representation for one
	 * time, you will never be confused again which index of Horst's matrixes means the line or row...<br>
	 * <br>
	 * Das Spielfeld. Es ist ein 2-Dimensionaler Array von char-Werten. Mehr ber deren Bedeutung siehe
	 * PubConstants. Das Spielfeld wird wie eine Matrix gespeichert (siehe Horst's Skript ungefr Seite 63).
	 * Die obere linke Ecke ist der Ursprung mit den Koordinaten (0, 0). Der erste Index reprsentiert die
	 * Zeile, der zweite die Spalte. Die Spielfeldzellen werden mit playFiled[line][row] adressiert.
	 * Bitte lasst euch davon nicht verwirren, wir mussten uns fr eine Darstellung entscheiden und
	 * haben diese gewhlt. Wenn ihr diese Darstellung ein mal gelernt habt, werdet ihr euch nie
	 * wieder von den Indizes von Horsts Matrizen irritieren lassen ;-).
	 * 
	 * @see PubConstants
	 */
	public char [][]playField = null;
}
